==========
Numerology
==========

Numerology calculates numbers from dates, names, other words::

    #!/usr/bin/env python

    from numerology import vedic

    print(vedic.name_number("Don't panic!"))

Only vedic numerology is implemented at the moment, gematria etc coming soon.
